## 连板天梯

接口：limit_step

描述：获取每天连板个数晋级的股票，可以分析出每天连续涨停进阶个数，判断强势热度

限量：单次最大2000行数据，可根据股票代码或者日期循环提取全部

积分：8000积分以上每分钟500次，每天总量不限制，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期（格式：YYYYMMDD，下同） |
| ts_code | str | N | 股票代码 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| nums | str | N | 连板次数，支持多个输入，例如nums='2,3' |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 代码 |
| name | str | Y | 名称 |
| trade_date | str | Y | 交易日期 |
| nums | str | Y | 连板次数 |

接口用法

```python
pro = ts.pro_api()

df = pro.limit_step(trade_date='20241125')
```

数据样例

```python
ts_code        name trade_date nums
0   000833.SZ  粤桂股份   20241125   11
```